// src/lib/get-casing-function.ts
function kebabCase(str) {
  return str.replace(/([a-z])([A-Z])/g, "$1-$2").replace(/[\s_]+/g, "-").toLowerCase();
}
function snakeCase(str) {
  return str.replace(/([a-z])([A-Z])/g, "$1_$2").replace(/[\s-]+/g, "_").toLowerCase();
}
function getCasingFunction(casing) {
  return casing === "kebab" ? kebabCase : snakeCase;
}

// src/lib/logger.ts
var Logger = class {
  level;
  constructor(level = "info") {
    this.level = level;
  }
  setLevel(level) {
    this.level = level;
  }
  shouldLog(messageLevel) {
    const levels = ["error", "warn", "info", "debug"];
    return levels.indexOf(messageLevel) <= levels.indexOf(this.level);
  }
  log(level, ...messages) {
    if (this.shouldLog(level)) {
      const formattedMessage = messages.map((m) => typeof m === "string" ? m : JSON.stringify(m)).join(" ");
      console.log(`[${level.toUpperCase()}] ${formattedMessage}`);
    }
  }
  error(err, ...messages) {
    const errorMessage = err instanceof Error ? err.message : err;
    this.log("error", errorMessage, ...messages);
  }
  warn(...messages) {
    this.log("warn", ...messages);
  }
  info(...messages) {
    this.log("info", ...messages);
  }
  debug(...messages) {
    this.log("debug", ...messages);
  }
};
var logger = new Logger();

export {
  getCasingFunction,
  logger
};
