import {
  logger
} from "./chunk-6VVQCB2M.mjs";

// src/codemods/helpers/update-source-value.ts
import path from "path";
function getUpdatedSource(j, source, casingFn) {
  if ("value" in source && typeof source.value === "string") {
    const newValue = transformPath(source.value, casingFn);
    if (newValue !== source.value) {
      if (source.type === "StringLiteral") {
        return j.stringLiteral(newValue);
      } else if (source.type === "Literal") {
        return j.literal(newValue);
      }
    }
  }
  return null;
}
var targetPathPrefixes = ["./", "../", "~/", "@/", "@src/", "#"];
function transformPath(filePath, casingFn) {
  const prefix = targetPathPrefixes.find((p) => filePath.startsWith(p));
  if (!prefix) {
    return filePath;
  }
  const pathWithoutPrefix = filePath.slice(prefix.length);
  const segments = pathWithoutPrefix.split(path.sep);
  const newSegments = segments.map((segment, index) => {
    if (index === segments.length - 1) {
      return convertFileName(segment, casingFn);
    }
    return convertSegment(segment, casingFn);
  });
  const newPath = prefix + newSegments.join(path.sep);
  return newPath;
}
function convertFileName(fileName, casingFn) {
  const ext = path.extname(fileName);
  const baseName = path.basename(fileName, ext);
  const convertedBaseName = convertSegment(baseName, casingFn);
  return convertedBaseName + ext;
}
function convertSegment(segment, casingFn) {
  if (segment.startsWith("[")) {
    return segment;
  }
  return casingFn(segment);
}

// src/codemods/helpers/update-imports-and-exports.ts
function updateImportsAndExports(j, root, casingFn) {
  let hasChanges = false;
  root.find(j.ImportDeclaration).forEach((path2) => {
    const newSource = getUpdatedSource(j, path2.node.source, casingFn);
    if (newSource) {
      path2.node.source = newSource;
      hasChanges = true;
    }
  });
  root.find(j.ExportNamedDeclaration).forEach((path2) => {
    if (path2.node.source) {
      const newSource = getUpdatedSource(j, path2.node.source, casingFn);
      if (newSource) {
        path2.node.source = newSource;
        hasChanges = true;
      }
    }
  });
  root.find(j.ExportAllDeclaration).forEach((path2) => {
    if (path2.node.source) {
      const newSource = getUpdatedSource(j, path2.node.source, casingFn);
      if (newSource) {
        path2.node.source = newSource;
        hasChanges = true;
      }
    }
  });
  root.find(j.TSImportType).forEach((path2) => {
    const newSource = getUpdatedSource(j, path2.node.argument, casingFn);
    if (newSource) {
      path2.node.argument = newSource;
      hasChanges = true;
    }
  });
  root.find(j.CallExpression, { callee: { name: "require" } }).forEach((path2) => {
    const arg = path2.node.arguments[0];
    const newSource = getUpdatedSource(j, arg, casingFn);
    if (newSource) {
      path2.node.arguments[0] = newSource;
      hasChanges = true;
    }
  });
  root.find(j.NewExpression, { callee: { name: "URL" } }).forEach((path2) => {
    const newSource = getUpdatedSource(j, path2.node.arguments[0], casingFn);
    if (newSource) {
      path2.node.arguments[0] = newSource;
      hasChanges = true;
    }
  });
  root.find(j.ImportExpression).forEach((path2) => {
    const newSource = getUpdatedSource(j, path2.node.source, casingFn);
    if (newSource) {
      path2.node.source = newSource;
      hasChanges = true;
    }
  });
  root.find(j.CallExpression, { callee: { name: "dynamic" } }).forEach((path2) => {
    logger.debug("Found dynamic() call in ", path2.name);
    const firstArg = path2.node.arguments.at(0);
    if (firstArg?.type === "ArrowFunctionExpression") {
      logger.debug("Has ArrowFunctionExpression");
      if (firstArg.body.type === "ImportExpression") {
        logger.debug("Has ImportExpression");
        const newSource = getUpdatedSource(j, firstArg.body.source, casingFn);
        if (newSource) {
          path2.node.arguments[0].body.source = newSource;
          hasChanges = true;
        }
      }
    }
  });
  return hasChanges ? root.toSource() : null;
}

export {
  updateImportsAndExports
};
