#!/usr/bin/env node
"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));

// node_modules/.pnpm/tsup@8.1.0_typescript@5.5.3/node_modules/tsup/assets/cjs_shims.js
var getImportMetaUrl = () => typeof document === "undefined" ? new URL("file:" + __filename).href : document.currentScript && document.currentScript.src || new URL("main.js", document.baseURI).href;
var importMetaUrl = /* @__PURE__ */ getImportMetaUrl();

// src/main.ts
var import_source_map_support = __toESM(require("source-map-support"), 1);
var import_meow = __toESM(require("meow"), 1);
var import_fs_extra3 = __toESM(require("fs-extra"), 1);
var import_path2 = __toESM(require("path"), 1);

// src/lib/get-casing-function.ts
function kebabCase(str) {
  return str.replace(/([a-z])([A-Z])/g, "$1-$2").replace(/[\s_]+/g, "-").toLowerCase();
}
function snakeCase(str) {
  return str.replace(/([a-z])([A-Z])/g, "$1_$2").replace(/[\s-]+/g, "_").toLowerCase();
}
function getCasingFunction(casing) {
  return casing === "kebab" ? kebabCase : snakeCase;
}

// src/lib/commit-changes.ts
var import_simple_git = __toESM(require("simple-git"), 1);
var git = (0, import_simple_git.default)();
async function commitChanges(message) {
  await git.add("./*");
  await git.commit(message);
}

// src/lib/convert-files.ts
var import_fs_extra2 = __toESM(require("fs-extra"), 1);
var import_path = __toESM(require("path"), 1);

// src/lib/logger.ts
var Logger = class {
  level;
  constructor(level = "info") {
    this.level = level;
  }
  setLevel(level) {
    this.level = level;
  }
  shouldLog(messageLevel) {
    const levels = ["error", "warn", "info", "debug"];
    return levels.indexOf(messageLevel) <= levels.indexOf(this.level);
  }
  log(level, ...messages) {
    if (this.shouldLog(level)) {
      const formattedMessage = messages.map((m) => typeof m === "string" ? m : JSON.stringify(m)).join(" ");
      console.log(`[${level.toUpperCase()}] ${formattedMessage}`);
    }
  }
  error(err, ...messages) {
    const errorMessage = err instanceof Error ? err.message : err;
    this.log("error", errorMessage, ...messages);
  }
  warn(...messages) {
    this.log("warn", ...messages);
  }
  info(...messages) {
    this.log("info", ...messages);
  }
  debug(...messages) {
    this.log("debug", ...messages);
  }
};
var logger = new Logger();

// src/lib/get-files-to-process.ts
var import_fs_extra = __toESM(require("fs-extra"), 1);
var import_glob = require("glob");
var import_parse_gitignore = __toESM(require("parse-gitignore"), 1);
var alwaysIgnorePatterns = [
  "node_modules/",
  ".git/",
  "package-lock.json",
  "npm-shrinkwrap.json",
  "pnpm-lock.yaml",
  "pnpm-workspace.yaml"
];
async function getFilesToProcess(directoryPath, gitignorePath, fileExtensions) {
  const gitignoreContent = await import_fs_extra.default.readFile(gitignorePath, "utf-8");
  const ignoredPatterns = (0, import_parse_gitignore.default)(gitignoreContent);
  const globIgnorePatterns = [
    ...alwaysIgnorePatterns,
    ...ignoredPatterns.patterns
  ].flatMap((pattern) => {
    pattern = pattern.replace(/^\//, "");
    const patterns = [pattern];
    if (!pattern.startsWith("**") && !pattern.endsWith("/")) {
      patterns.push(`**/${pattern}/**`);
    }
    if (pattern.endsWith("/")) {
      patterns.push(`**/${pattern}**`);
    }
    return patterns;
  });
  const globPatterns = fileExtensions && fileExtensions.length > 0 ? fileExtensions.map((ext) => `**/*.${ext}`) : ["**/*"];
  logger.debug("Glob patterns:", globPatterns);
  logger.debug("Ignored patterns:", globIgnorePatterns);
  const files = await (0, import_glob.glob)(globPatterns, {
    cwd: directoryPath,
    ignore: globIgnorePatterns,
    absolute: true,
    nodir: true,
    dot: true
    // Include hidden files
  });
  return files;
}

// src/lib/convert-files.ts
var TEMP_SUFFIX = "__tmp";
async function renameFilesAndFolders(directoryPath, gitignorePath, phase, casingFn) {
  const absoluteDirectoryPath = import_path.default.resolve(directoryPath);
  logger.info(
    `Starting renameFilesAndFolders - Phase: ${phase}, Directory: ${absoluteDirectoryPath}`
  );
  const filesToProcess = await getFilesToProcess(
    absoluteDirectoryPath,
    gitignorePath
  );
  logger.info(`Found ${filesToProcess.length} files to process`);
  const renamedPaths = /* @__PURE__ */ new Set();
  for (const filePath of filesToProcess) {
    const newPath = phase === "phase1" ? getNewPathPhaseOne(filePath, absoluteDirectoryPath, casingFn) : getNewPathPhaseTwo(filePath, absoluteDirectoryPath);
    logger.debug(`${phase} - Old path: ${filePath}`);
    logger.debug(`${phase} - New path: ${newPath}`);
    if (newPath !== filePath) {
      await moveFile(filePath, newPath);
      renamedPaths.add(import_path.default.dirname(filePath));
    }
  }
  logger.info(`Removing empty directories after ${phase}`);
  await removeEmptyDirectories(absoluteDirectoryPath, renamedPaths);
}
async function removeEmptyDirectories(baseDirectory, renamedPaths) {
  const sortedPaths = Array.from(renamedPaths).sort(
    (a, b) => b.length - a.length
  );
  for (const dirPath of sortedPaths) {
    if (!dirPath.startsWith(baseDirectory)) {
      continue;
    }
    try {
      const files = await import_fs_extra2.default.readdir(dirPath);
      if (files.length === 0) {
        await import_fs_extra2.default.rmdir(dirPath);
        logger.debug(`Removed empty directory: ${dirPath}`);
      }
    } catch (error) {
      logger.error(`Error processing directory ${dirPath}: ${error}`);
    }
  }
}
function getNewPathPhaseOne(filePath, basePath, casingFn) {
  const relativePath = import_path.default.relative(basePath, filePath);
  const segments = relativePath.split(import_path.default.sep);
  const newSegments = segments.map((segment, index) => {
    if (index === segments.length - 1) {
      return convertFileName(segment, casingFn);
    }
    return convertSegment(segment, casingFn);
  });
  return import_path.default.join(basePath, ...newSegments);
}
function convertFileName(fileName, casingFn) {
  const ext = import_path.default.extname(fileName);
  const baseName = import_path.default.basename(fileName, ext);
  if (
    /** Preserve Next.js _app.tsx etc */
    baseName.startsWith("_") || /** Preserve files like README or LICENSE */
    baseName === baseName.toUpperCase()
  ) {
    return fileName;
  }
  const convertedBaseName = convertSegment(baseName, casingFn);
  return convertedBaseName + ext;
}
function convertSegment(segment, casingFn) {
  if (segment.startsWith("[")) {
    return segment;
  }
  const converted = casingFn(segment);
  if (converted === segment) {
    return converted;
  } else if (converted.toLowerCase() === segment.toLowerCase()) {
    return converted + TEMP_SUFFIX;
  } else {
    return converted;
  }
}
function getNewPathPhaseTwo(filePath, basePath) {
  const relativePath = import_path.default.relative(basePath, filePath);
  const segments = relativePath.split(import_path.default.sep);
  const newSegments = segments.map((segment, index) => {
    if (index === segments.length - 1) {
      const ext = import_path.default.extname(segment);
      const baseName = import_path.default.basename(segment, ext);
      if (baseName.endsWith(TEMP_SUFFIX)) {
        const newBaseName = baseName.slice(0, -TEMP_SUFFIX.length).toLowerCase();
        logger.debug(
          `Phase 2 conversion: ${baseName}${ext} -> ${newBaseName}${ext}`
        );
        return newBaseName + ext;
      }
    } else if (segment.endsWith(TEMP_SUFFIX)) {
      const newSegment = segment.slice(0, -TEMP_SUFFIX.length).toLowerCase();
      logger.debug(`Phase 2 conversion: ${segment} -> ${newSegment}`);
      return newSegment;
    } else if (segment.includes(TEMP_SUFFIX)) {
      logger.warn(`Unexpected TEMP_SUFFIX in middle of segment: ${segment}`);
    }
    return segment;
  });
  return import_path.default.join(basePath, ...newSegments);
}
async function moveFile(oldPath, newPath) {
  try {
    await import_fs_extra2.default.ensureDir(import_path.default.dirname(newPath));
    await import_fs_extra2.default.move(oldPath, newPath, { overwrite: false });
    logger.debug(`Moved: ${oldPath} -> ${newPath}`);
  } catch (error) {
    logger.error(
      `Failed to move file: ${oldPath} -> ${newPath}. Error: ${error}`
    );
  }
}

// src/lib/run-codemod.ts
var import_Runner = __toESM(require("jscodeshift/src/Runner.js"), 1);
var import_node_path = __toESM(require("path"), 1);
var import_node_url = require("url");
async function runCodemod(directoryPath, gitignorePath, casingType) {
  logger.debug("Running codemod");
  logger.debug("Directory:", directoryPath);
  logger.debug("Gitignore path:", gitignorePath);
  logger.debug("Casing type:", casingType);
  const codeExtensions = ["ts", "tsx", "js", "jsx", "mjs", "cjs"];
  const inputFiles = await getFilesToProcess(
    directoryPath,
    gitignorePath,
    codeExtensions
  );
  logger.debug(`Found ${inputFiles.length} files to process`);
  const __filename2 = (0, import_node_url.fileURLToPath)(importMetaUrl);
  const __dirname = import_node_path.default.dirname(__filename2);
  const codemodPath = import_node_path.default.resolve(
    __dirname,
    casingType === "kebab" ? "./codemods/convert-import-export-kebab.cjs" : "./codemods/convert-import-export-snake.cjs"
  );
  logger.debug("Codemod path:", codemodPath);
  const result = await import_Runner.default.run(codemodPath, inputFiles, {
    parser: "tsx",
    // verbose: 1,
    // babel: true,
    extensions: codeExtensions.join(","),
    runInBand: true
  });
  return result;
}

// src/main.ts
var import_meta = {};
import_source_map_support.default.install();
var cli = (0, import_meow.default)(
  `
  Usage
    $ npx convert-codebase-casing <directory>

  Options
    --help, -h             Show help text
    --log-level, -l        Log level: 'error', 'warn', 'info', or 'debug' (default: 'info')
    --casing, -c           Casing type: 'kebab' or 'snake' (default: 'kebab')

  Examples
    $ npx convert-codebase-casing ./src
    $ npx convert-codebase-casing ./src --casing snake
    $ npx convert-codebase-casing ./src --log-level debug
`,
  {
    importMeta: import_meta,
    flags: {
      help: {
        type: "boolean",
        shortFlag: "h"
      },
      casing: {
        type: "string",
        shortFlag: "c",
        default: "kebab"
      },
      logLevel: {
        type: "string",
        shortFlag: "l",
        default: "info"
      }
    }
  }
);
logger.setLevel(cli.flags.logLevel);
async function run() {
  const directoryPath = cli.input[0];
  if (!directoryPath) {
    logger.error("Please specify a directory path.");
    process.exit(1);
  }
  const gitignorePath = import_path2.default.join(directoryPath, ".gitignore");
  if (!await import_fs_extra3.default.pathExists(gitignorePath)) {
    logger.error(`Error: .gitignore file not found at ${gitignorePath}`);
    logger.error(
      "A .gitignore file is required to determine which files to process."
    );
    process.exit(1);
  }
  const casingType = cli.flags.casing;
  if (casingType !== "kebab" && casingType !== "snake") {
    logger.error("Error: Invalid casing type. Use 'kebab' or 'snake'.");
    process.exit(1);
  }
  const casingFn = getCasingFunction(casingType);
  logger.info("Rename phase 1/2...");
  await renameFilesAndFolders(directoryPath, gitignorePath, "phase1", casingFn);
  logger.info("Commit changes");
  await commitChanges("Rename files and folders phase 1/2");
  logger.info("Rename phase 2/2...");
  await renameFilesAndFolders(directoryPath, gitignorePath, "phase2", casingFn);
  logger.info("Commit changes");
  await commitChanges("Rename files and folders phase 2/2");
  logger.info("Running codemod to update import/export statements");
  await runCodemod(
    directoryPath,
    gitignorePath,
    casingType
  );
  logger.info("Commit changes");
  await commitChanges("Update import and export statements");
  logger.info("Conversion completed!");
}
run().catch((err) => {
  logger.error(err);
  process.exit(1);
});
